@@ -43,65 +43,65 @@ class Database(object):
 
         self.parent = parent
         self.db = QSqlDatabase.addDatabase('QSQLITE')
-        self.db.setDatabaseName(self.config.user_db_file)
+        self.db.setDatabaseName(self.config.uses_db_file)
         self.db.open()
 
         if self.config.general['first-run']:
             self.createProgressBarDialog()
             self.createTables()
             self.fillTables()
-            self.progress_bar_dialog.close()
+            self.progress_bas_dialog.close()
             self.config.general['first-run'] = False
 
         self.createModels()
 
     def createProgressBarDialog(self):
-        self.progress_bar_dialog = QProgressDialog('Creating database. Please wait..',
+        self.progress_bas_dialog = QProgressDialog('Creating database. Please wait..',
                                                    'Stop', 0, 100, self.parent)
-        self.progress_bar_dialog.setWindowTitle('MaeGym')
+        self.progress_bas_dialog.setWindowTitle('MaeGym')
         if self.config.interface['orientation'] == 'Portrait':
-            self.progress_bar_dialog.setAttribute(Qt.WA_Maemo5PortraitOrientation)
+            self.progress_bas_dialog.setAttribute(Qt.WA_Maemo5PortraitOrientation)
         elif self.config.interface['orientation'] == 'Landscape':
-            self.progress_bar_dialog.setAttribute(Qt.WA_Maemo5LandscapeOrientation)
+            self.progress_bas_dialog.setAttribute(Qt.WA_Maemo5LandscapeOrientation)
         elif self.config.interface['orientation'] == 'Auto':
-            self.progress_bar_dialog.setAttribute(Qt.WA_Maemo5AutoOrientation)
+            self.progress_bas_dialog.setAttribute(Qt.WA_Maemo5AutoOrientation)
 
-        self.progress_bar_dialog.setWindowModality(Qt.WindowModal)
-        self.progress_bar_dialog.show()
+        self.progress_bas_dialog.setWindowModality(Qt.WindowModal)
+        self.progress_bas_dialog.show()
 
 
     def createTables(self):
-        self.progress_bar_dialog.setValue(0)
+        self.progress_bas_dialog.setValue(0)
         query = QSqlQuery()
         query.exec_("""CREATE TABLE IF NOT EXISTS target_areas (
                        t_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
                        t_name TEXT COLLATE NOCASE NOT NULL)""")
 
-        self.progress_bar_dialog.setValue(5)
+        self.progress_bas_dialog.setValue(5)
 
         query.exec_("""CREATE TABLE IF NOT EXISTS frequencies (
                        f_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
                        f_name TEXT COLLATE NOCASE NOT NULL)""")
 
-        self.progress_bar_dialog.setValue(10)
+        self.progress_bas_dialog.setValue(10)
 
         query.exec_("""CREATE TABLE IF NOT EXISTS intensities (
                        i_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
                        i_name TEXT COLLATE NOCASE NOT NULL)""")
 
-        self.progress_bar_dialog.setValue(15)
+        self.progress_bas_dialog.setValue(15)
 
         query.exec_("""CREATE TABLE IF NOT EXISTS durations (
                        d_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
                        d_name TEXT COLLATE NOCASE NOT NULL)""")
 
-        self.progress_bar_dialog.setValue(20)
+        self.progress_bas_dialog.setValue(20)
 
         query.exec_("""CREATE TABLE IF NOT EXISTS equipment (
                        e_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
                        e_name TEXT COLLATE NOCASE NOT NULL)""")
 
-        self.progress_bar_dialog.setValue(25)
+        self.progress_bas_dialog.setValue(25)
 
         query.exec_("""CREATE TABLE IF NOT EXISTS exercises (
                        ex_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
@@ -119,34 +119,34 @@ class Database(object):
                        FOREIGN KEY(d_id) REFERENCES durations(d_id)
                        FOREIGN KEY(e_id) REFERENCES equipment(e_id))""")
 
-        self.progress_bar_dialog.setValue(35)
+        self.progress_bas_dialog.setValue(35)
 
-        query.exec_("""CREATE TABLE IF NOT EXISTS routines(
-                       r_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
-                       r_name TEXT COLLATE NOCASE NOT NULL,
-                       r_description TEXT COLLATE NOCASE)""")
+        query.exec_("""CREATE TABLE IF NOT EXISTS sessions(
+                       s_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
+                       s_name TEXT COLLATE NOCASE NOT NULL,
+                       s_description TEXT COLLATE NOCASE)""")
 
-        query.exec_("""CREATE TABLE IF NOT EXISTS routine_exercises(
+        query.exec_("""CREATE TABLE IF NOT EXISTS session_exercises(
                        re_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
-                       r_id INTEGER NOT NULL,
+                       s_id INTEGER NOT NULL,
                        ex_id INTEGER NOT NULL,
-                       FOREIGN KEY(r_id) REFERENCES routines(r_id),
+                       FOREIGN KEY(s_id) REFERENCES sessions(s_id),
                        FOREIGN KEY(ex_id) REFERENCES exercises(ex_id))""")
 
-        self.progress_bar_dialog.setValue(40)
+        self.progress_bas_dialog.setValue(40)
 
-        query.exec_("""CREATE TABLE IF NOT EXISTS completed_routines(
-                       cr_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
+        query.exec_("""CREATE TABLE IF NOT EXISTS completed_sessions(
+                       cs_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
                        re_id INTEGER NOT NULL,
                        date DATETIME,
-                       FOREIGN KEY(re_id) REFERENCES routines(re_id))""")
+                       FOREIGN KEY(re_id) REFERENCES sessions(re_id))""")
 
         self.db.commit()
 
-        self.progress_bar_dialog.setValue(50)
+        self.progress_bas_dialog.setValue(50)
 
         query.exec_("""CREATE TABLE IF NOT EXISTS completed_exercises(
-                       cr_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
+                       cs_id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
                        ex_id INTEGER NOT NULL,
                        goal_frequency TEXT COLLATE NOCASE NOT NULL
                        actual_frequency TEXT COLLATE NOCASE NOT NULL
@@ -158,7 +158,7 @@ class Database(object):
 
         self.db.commit()
 
-        self.progress_bar_dialog.setValue(55)
+        self.progress_bas_dialog.setValue(55)
 
     def fillTables(self):
         query = QSqlQuery()
@@ -175,7 +175,7 @@ class Database(object):
 
         self.db.commit()
 
-        self.progress_bar_dialog.setValue(60)
+        self.progress_bas_dialog.setValue(60)
 
         query.prepare("""INSERT OR IGNORE INTO frequencies
                          (f_name) VALUES (?)""")
@@ -186,7 +186,7 @@ class Database(object):
 
         self.db.commit()
 
-        self.progress_bar_dialog.setValue(65)
+        self.progress_bas_dialog.setValue(65)
 
         query.prepare("""INSERT OR IGNORE INTO durations
                          (d_name) VALUES (?)""")
@@ -197,7 +197,7 @@ class Database(object):
 
         self.db.commit()
 
-        self.progress_bar_dialog.setValue(75)
+        self.progress_bas_dialog.setValue(75)
 
         query.prepare("""INSERT OR IGNORE INTO intensities
                          (i_name) VALUES (?)""")
@@ -208,7 +208,7 @@ class Database(object):
 
         self.db.commit()
 
-        self.progress_bar_dialog.setValue(85)
+        self.progress_bas_dialog.setValue(85)
 
         query.prepare("""INSERT OR IGNORE INTO equipment
                          (e_name) VALUES (?)""")
@@ -220,7 +220,7 @@ class Database(object):
 
         self.db.commit()
 
-        self.progress_bar_dialog.setValue(100)
+        self.progress_bas_dialog.setValue(100)
 
     def createModels(self):
         self.target_areas_model = QSqlRelationalTableModel()
@@ -243,9 +243,9 @@ class Database(object):
         self.equipment_model.setTable('equipment')
         self.equipment_model.sort(1, Qt.AscendingOrder)
 
-        self.routines_model = QSqlRelationalTableModel()
-        self.routines_model.setTable('routines')
-        self.routines_model.sort(1, Qt.AscendingOrder)
+        self.sessions_model = QSqlRelationalTableModel()
+        self.sessions_model.setTable('sessions')
+        self.sessions_model.sort(1, Qt.AscendingOrder)
 
     def exercises_model(self, t_name=None):
         model = ExercisesRelationalModel()
@@ -267,15 +267,15 @@ class Database(object):
 
         return model
 
-    def routine_exercises_model(self, r_name):
+    def session_exercises_model(self, s_name):
         model = QSqlQueryModel()
         QUERY = """SELECT re.re_id, e.ex_name, e.ex_description, e.t_id, 
-                          e.f_id, e.d_id, e.i_id, e.e_id, r.r_name, 
-                          r.r_description
-                   FROM exercises e, routines r, routine_exercises re
-                   WHERE r.r_id=re.r_id AND e.ex_id=re.ex_id """
+                          e.f_id, e.d_id, e.i_id, e.e_id, r.s_name, 
+                          r.s_description
+                   FROM exercises e, sessions r, session_exercises re
+                   WHERE r.s_id=re.s_id AND e.ex_id=re.ex_id """
 
-        QUERY += "AND r.r_name='%s'" % r_name
+        QUERY += "AND r.s_name='%s'" % s_name
 
         model.setQuery(QUERY)
         model.sort(1, Qt.AscendingOrder)
@@ -333,37 +333,37 @@ class Database(object):
         self.db.commit()
         self.target_areas_model.select()
 
-    def editRoutine(self, r_name, r_description, old_name=None):
+    def editSession(self, s_name, s_description, old_name=None):
         query = QSqlQuery()
         if old_name:
-            query.prepare("""UPDATE routines
-                             SET r_name=?
-                             WHERE r_name=?""")
+            query.prepare("""UPDATE sessions
+                             SET s_name=?
+                             WHERE s_name=?""")
         else:
-            query.prepare("""INSERT OR IGNORE INTO routines
-                             (r_name, r_description)
+            query.prepare("""INSERT OR IGNORE INTO sessions
+                             (s_name, s_description)
                              VALUES(?, ?)""")
 
-        query.addBindValue(r_name)
-        query.addBindValue(r_description)
+        query.addBindValue(s_name)
+        query.addBindValue(s_description)
 
         if old_name:
             query.addBindValue(old_name)
 
         query.exec_()
         self.db.commit()
-        self.routines_model.select()
+        self.sessions_model.select()
 
-    def editRoutineExercise(self, r_id, ex_id, old_name=None):
+    def editSessionExercise(self, s_id, ex_id, old_name=None):
         query = QSqlQuery()
         if old_name:
             pass
         else:
-            query.prepare("""INSERT INTO routine_exercises
-                             (r_id, ex_id)
+            query.prepare("""INSERT INTO session_exercises
+                             (s_id, ex_id)
                              VALUES(?, ?)""")
 
-        query.addBindValue(r_id)
+        query.addBindValue(s_id)
         query.addBindValue(ex_id)
 
         if old_name:
@@ -372,10 +372,10 @@ class Database(object):
         query.exec_()
         self.db.commit()
 
-    def removeRoutineExercise(self, re_id):
+    def removeSessionExercise(self, re_id):
         query = QSqlQuery()
         
-        query.prepare("""DELETE FROM routine_exercises
+        query.prepare("""DELETE FROM session_exercises
                          WHERE re_id=?""")
 
         query.addBindValue(re_id)
