@@ -30,9 +30,10 @@ import config as c
 
 # program modules 
 from ui.ui_exercises_window import Ui_ExercisesWindow
-import routines_window as ww
+import sessions_window as ww
 import exercise_wizard as ew
 import target_areas_window as taw
+import view_exercise_window as vew
 
 from delegates import ExercisesDelegate
 
@@ -73,7 +74,7 @@ class ExercisesWindow(QMainWindow, Ui_ExercisesWindow):
 
         if t_name:    
             self.target_areas_action.setEnabled(False)
-            self.routines_action.setEnabled(False)
+            self.sessions_action.setEnabled(False)
             self.new_exercise_button.hide()
             self.setWindowTitle(t_name)
 
@@ -82,11 +83,11 @@ class ExercisesWindow(QMainWindow, Ui_ExercisesWindow):
         self.exercises_list_view.setItemDelegate(ExercisesDelegate())
 
     @pyqtSignature('bool')
-    def on_routines_action_triggered(self, checked):
-        self.config.interface['last-fitness'] = 'routines'
+    def on_sessions_action_triggered(self, checked):
+        self.config.interface['last-fitness'] = 'sessions'
         self.parent().setFitnessWindow()
-        routines_window = ww.RoutinesWindow(self.parent(), self.db)
-        routines_window.show()
+        sessions_window = ww.SessionsWindow(self.parent(), self.db)
+        sessions_window.show()
         self.hide()
 
     @pyqtSignature('bool')
@@ -99,6 +100,7 @@ class ExercisesWindow(QMainWindow, Ui_ExercisesWindow):
 
     @pyqtSignature('bool')
     def on_delete_exercises_action_triggered(self, checked):
+        self.exercises_list_view.blockSignals(True)
         def deleteExercises():
             indexes = []
             for index in self.exercises_list_view.selectedIndexes():
@@ -131,7 +133,27 @@ class ExercisesWindow(QMainWindow, Ui_ExercisesWindow):
 
     @pyqtSignature('QModelIndex')
     def on_exercises_list_view_clicked(self, index):
-        pass
+        filename = self.model.record(index.row()).value('ex_media').toString()
+        ex_name = self.model.record(index.row()).value('ex_name').toString()
+        t_name = self.model.record(index.row()).value('t_name').toString()
+        f_name = self.model.record(index.row()).value('f_name').toString()
+        d_name = self.model.record(index.row()).value('d_name').toString()
+        i_name = self.model.record(index.row()).value('i_name').toString()
+        e_name = self.model.record(index.row()).value('e_name').toString()
+
+        print e_name
+
+        title = "%s (%s)" %(ex_name, t_name)
+
+        view_exercise_window = vew.ViewExerciseWindow(filename, self, self.db)
+        view_exercise_window.setWindowTitle(title)
+        view_exercise_window.frequency_value_button.setValueText(f_name)
+        view_exercise_window.duration_value_button.setValueText(d_name)
+        view_exercise_window.intensity_value_button.setValueText(i_name)
+        view_exercise_window.equipment_value_button.setValueText(e_name)
+
+        view_exercise_window.show()
+
 
     def exitFullScreen(self):
         self.exercises_list_view.clearSelection()
@@ -139,6 +161,7 @@ class ExercisesWindow(QMainWindow, Ui_ExercisesWindow):
         self.new_exercise_button.setVisible(True)
         self.edit_bar.setVisible(False)
         self.showNormal()
+        self.exercises_list_view.blockSignals(False)
 
     def openMenu(self, position):
         menu = QMenu(self)
