@@ -17,6 +17,7 @@ class ExampleMediaPlayer(Phonon.VideoPlayer):
         self.load(Phonon.MediaSource(filename))
 
     def mouseReleaseEvent(self, event):
+        print self.filename
         if self.isFullScreen():
             self.setWindowFlags(Qt.Widget)
             self.showNormal()
@@ -34,5 +35,6 @@ if __name__ == '__main__':
     app = QApplication(sys.argv)
     app.setApplicationName('MaeGym')
     example = ExampleMediaPlayer()
-    example.setFilename('http://www.quintic.com/education/case_studies_videos/Flat_Bench_SV.avi')
+    example.setFilename('/home/user/MyDocs/seated_cable_row.flv')
+    example.show()
     sys.exit(app.exec_())
