@@ -32,11 +32,12 @@ from ui.ui_view_exercise_window import Ui_ViewExerciseWindow
 
 class ViewExerciseWindow(QMainWindow, Ui_ViewExerciseWindow):
 
-    def __init__(self, parent=None, database=None):
+    def __init__(self, filename, parent=None, database=None):
         super(ViewExerciseWindow, self).__init__(parent)
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
 
         self.setupUi(self)
+        self.example_media_player.setFilename(filename)
         self.config = c.Config()
         self.db = database
         self.reflowWidgets()
@@ -64,20 +65,6 @@ class ViewExerciseWindow(QMainWindow, Ui_ViewExerciseWindow):
 
             self.central_widget.layout().addLayout(top_h_box)
             self.central_widget.layout().addLayout(bottom_h_box)
-
-            """
-            left_v_box = QVBoxLayout()
-            left_v_box.addWidget(self.example_media_player)
-            
-            right_v_box = QVBoxLayout()
-            right_v_box.addWidget(self.duration_value_button)
-            right_v_box.addWidget(self.frequency_value_button)
-            right_v_box.addWidget(self.intensity_value_button)
-            right_v_box.addWidget(self.equipment_value_button)
-
-            self.central_widget.layout().addLayout(left_v_box)
-            self.central_widget.layout().addLayout(right_v_box)
-            """
         else:
             self.central_widget.setLayout(QVBoxLayout())
 
